@@ -1,12 +1,12 @@
 #
-#  Copyright (C) 2000-2004 Jonas Beskow and Kare Sjolander 
+#  Copyright (C) 2000-2005 Jonas Beskow and Kare Sjolander 
 #
 # This file is part of the WaveSurfer package.
 # The latest version can be found at http://www.speech.kth.se/wavesurfer/
 #
 # lappend auto_path .
 package require surfutil
-package provide wsurf 1.7
+package provide wsurf 1.8
 
 namespace eval vtcanvas {
  variable Info
@@ -22,7 +22,7 @@ namespace eval vtcanvas {
    -stipple         stipple            "" \
    -layer           layer              bottom \
    -fillcolor       fillColor          lightyellow \
-   -framecolor      frameColor         yellow \
+   -framecolor      frameColor         orange \
    -cursorcolor     cursorColor        red \
    -cursorpos       cursorPos          "" \
    -closeenough     @canvas            3.0 \
@@ -47,6 +47,7 @@ namespace eval vtcanvas {
    -yaxisfont       yaxisFont          {Helvetica 8} \
    -displaylength   displaylength      1 \
    -formattimecommand formatTimeCommand {} \
+   -state           state              normal \
  ]
 
  list {
@@ -257,6 +258,10 @@ proc vtcanvas::configure {w args} {
      }
     }
     -yaxiswidth {
+     if {$val == 0} {
+      $w.ff  configure -bd 0
+      $w.yaxis configure -bd 0
+     }
      $wid(yaxis) configure -width $val
     }
     -yscrollbar {
@@ -301,6 +306,9 @@ proc vtcanvas::configure {w args} {
      set d(yaxisFont) $val
      if {[string match $d(showYaxis) true]} {set drax 1}
     }
+    -state {
+     set d(state) $val
+    }
     default {
      if {[string match @* $OptionMap($opt)]} {
       foreach tkwid [split [string range $OptionMap($opt) 1 end] :] {
@@ -497,7 +505,7 @@ proc vtcanvas::selectionEvent {w event item x y t} {
 
  set c  [$w canvas]
  set xc [$c canvasx $x]
- if {$d(pixelsPerSecond) == 0} return
+ if {$d(pixelsPerSecond) == 0 || [string equal "normal" $d(state)] == 0} return
  set xtime [expr {$xc/double($d(pixelsPerSecond))}]
  if {[string match <*ButtonPress-1> ${event}] && $d(displaylength)} {
    $c create rectangle -1 -1 -1 -1 -fill $d(frameColor) -tags selbg
@@ -678,7 +686,7 @@ proc vtcanvas::drawYAxis {w canvas {x 0} {y 0} {tags yaxis}} {
  set height [$w cget -scrollheight]
  set valPerTick 0.00001
 
- if {$maxval == 0 || $maxval == $minval} return
+ if {$maxval == $minval} return
  #<< "maxval = $maxval, minval = $minval"
  set dy [expr {double($height * $valPerTick) / ($maxval - $minval)}]
 
