@@ -1,13 +1,13 @@
 #
-#  Copyright (C) 2000-2004 Jonas Beskow and Kare Sjolander 
+#  Copyright (C) 2000-2005 Jonas Beskow and Kare Sjolander 
 #
 # This file is part of the WaveSurfer package.
 # The latest version can be found at http://www.speech.kth.se/wavesurfer/
 #
 
-package provide wsurf 1.7
+package provide wsurf 1.8
 package require snack 2.2
-package require surfutil 1.7
+package require surfutil 1.8
 
 namespace eval wavebar {
  variable Info
@@ -47,6 +47,10 @@ namespace eval wavebar {
     -pixelspersecond    0.0 \
     -zoomevent          {{Shift 1} 2} \
     ]
+  if {$::useTile} {
+#   lappend Info(OptionTable) -foreground $::tile::colors(-selectfg) \
+     -background $::tile::colors(-selectbg)
+  }
   set Info(emptysound) [snack::sound]
   set Info(Initialized) 1
   set Info(debug) $::wsurf::Info(debug)
